Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(4660)

Unified Diff: cc/surfaces/compositor_frame_sink_support.h

Issue 2565783002: Moves ownership of the cc::Display's BeginFrameSource out of Display. (Closed)
Patch Set: rebase. Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: cc/surfaces/compositor_frame_sink_support.h
diff --git a/cc/surfaces/compositor_frame_sink_support.h b/cc/surfaces/compositor_frame_sink_support.h
index f9973d31f9fb276c7ba69eaa997d27fa5052a17f..1ffa5927fe74884999fe22dc5adf78fe4ed8d30c 100644
--- a/cc/surfaces/compositor_frame_sink_support.h
+++ b/cc/surfaces/compositor_frame_sink_support.h
@@ -26,10 +26,12 @@ class CC_SURFACES_EXPORT CompositorFrameSinkSupport
public SurfaceFactoryClient,
public BeginFrameObserver {
public:
- CompositorFrameSinkSupport(CompositorFrameSinkSupportClient* client,
- SurfaceManager* surface_manager,
- const FrameSinkId& frame_sink_id,
- std::unique_ptr<Display> display);
+ CompositorFrameSinkSupport(
+ CompositorFrameSinkSupportClient* client,
+ SurfaceManager* surface_manager,
+ const FrameSinkId& frame_sink_id,
+ std::unique_ptr<Display> display,
+ std::unique_ptr<BeginFrameSource> display_begin_frame_source);
~CompositorFrameSinkSupport() override;
@@ -73,9 +75,10 @@ class CC_SURFACES_EXPORT CompositorFrameSinkSupport
const FrameSinkId frame_sink_id_;
- // GpuCompositorFrameSink holds a Display if it created with
- // non-null gpu::SurfaceHandle. In the window server, the display root
- // window's CompositorFrameSink will have a valid gpu::SurfaceHandle.
+ // GpuCompositorFrameSink holds a Display and its BeginFrameSource if it
+ // created with non-null gpu::SurfaceHandle. In the window server, the display
+ // root window's CompositorFrameSink will have a valid gpu::SurfaceHandle.
+ std::unique_ptr<BeginFrameSource> display_begin_frame_source_;
std::unique_ptr<Display> display_;
LocalFrameId local_frame_id_;
« no previous file with comments | « blimp/client/support/compositor/blimp_embedder_compositor.cc ('k') | cc/surfaces/compositor_frame_sink_support.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698